// Weather.cpp: implementation of the CWeather class.
//
//////////////////////////////////////////////////////////////////////

#include <cstddef>

#include "WeatherReport.h"
#include "Weather.h"
#include "Climate.h"
#include "Dice.h"

string CWeather::m_strNames[] = {
    "Precipitation",
    "Overcast",
    "Typhoon",
    "Clear"
};

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CWeather::CWeather(int nWeather) 
{
	m_nType = nWeather;
}

CWeather::~CWeather()
{

}

CWeather& CWeather::operator=(const CWeather& rhs)
{
	m_nType = rhs.m_nType;
	m_bCatastrophe = rhs.m_bCatastrophe;
	return *this;
}

string CWeather::getName() const
{
	return m_strNames[m_nType];
}

bool CWeather::isCatastrophe() const
{
	return m_bCatastrophe;
}

void CWeather::clearCatastrophe()
{
    m_bCatastrophe = false;
}

void CWeather::randomType()
{
     int roll;
         
	 m_nType = CLEAR;

     /* get die-roll.  if catastrophe, set flag and roll again. */
     m_bCatastrophe = false;
     do {  
         roll = CDice::roll(100);
         if (roll == 100)
		 {
             m_bCatastrophe = true;
		 }
     }
     while (roll == 100);
 
     /* if it rained more than a sprinkle yesterday, it more likely */
     /* to be at least overcast, if not rainy today. */
	 CWeatherReport* pReport = CWeatherReport::instance();
	 CWeatherReport* pYesterday = pReport->getYesterday();
     if (pYesterday->getPrecip() > CPrecip::SPRINKLE) {
         roll = roll - 10;
         if (roll < 1)
             roll = 1;
     }

     /* find the type of weather from the die-roll */
	 CClimate* pClimate = pReport->getClimate();
	 int nMonth = pReport->getMonth();
     for (int i = CLEAR; i >= PRECIPITATION; i--)
	 {
         if ( roll <= pClimate->getWeather(nMonth, i) )
		 {
             m_nType = i;
		 }
	 }
}

