// WeatherReport.h: interface for the CWeatherReport class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(_WEATHERREPORT_H)
#define _WEATHERREPORT_H

class CCalendar;
class CClimate;

#include "Weather.h"
#include "Wind.h"
#include "Temperature.h"
#include "Precip.h"
#include "Overcast.h"

class CStats;

class CWeatherReport  
{
public:
	virtual ~CWeatherReport();

	static CWeatherReport* instance();
	void init();
	void initWinter();
	void generate(int nDay, int nMonth, int nYear);
	void print() const;
	void printYearHeader() const;
	void printYearFooter() const;
	void printMonthHeader() const;
	void printMonthFooter() const;
	int getWeather() const;
	int getWind() const;
	int getTemp() const;
	int getTempDegrees() const;
	int getPrecip() const;
	int getOvercast() const;
	int getMonth() const;
	bool isSnow() const;
	CClimate* getClimate() const;
	CCalendar* getCalendar() const;
	CWeatherReport* getYesterday() const;
	void setWeather(int nWeather);
	CWeatherReport& operator= (const CWeatherReport& rhs);

protected:
	CWeatherReport();
	CWeather m_cWeather;
	CWind m_cWind;
	CTemperature m_cTemp;
	CPrecip m_cPrecip;
	COvercast m_cOvercast;
	int m_nDay;
	int m_nMonth;
	int m_nYear;
	CStats* m_pStat;
	CCalendar* m_pCalendar;
	CClimate* m_pClimate;
	CWeatherReport* m_pYesterday;
	static CWeatherReport* m_pInstance;
};

#endif // !defined(_WEATHERREPORT_H)


