// Wind.cpp: implementation of the CWind class.
//
//////////////////////////////////////////////////////////////////////

#include "Wind.h"
#include "WeatherReport.h"
#include "Weather.h"
#include "Climate.h"
#include "Dice.h"

string CWind::m_strNames[] = {
    "Calm",
    "Light",
    "Brisk",
    "Blustery",
    "Gale",
};

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CWind::CWind(int nWind)
{
	m_nType = nWind;
}

CWind::~CWind()
{

}

string CWind::getName() const
{
	return m_strNames[m_nType];
}


void CWind::randomType()
{
     int roll = CDice::roll(100);
	 CWeatherReport* pReport = CWeatherReport::instance();
	 int nWeather = pReport->getWeather();

     m_nType = GALE;

	 // Immediately return if weather is TAIFUN
     if (nWeather == CWeather::TAIFUN)
	 {
         m_nType = GALE;
		 return;
	 }

     /* modify the roll for current weather.  Clear weather is less likely */
     /* to be windy, and rainy weather is more likely. */
     if (nWeather == CWeather::CLEAR)
	 {
         roll -= 20;
	 }
	 else if (nWeather == CWeather::PRECIPITATION)
	 {
         roll += 20;
	 }

     /* if yesterday was very windy, today will be windier */
	 CWeatherReport* pYesterday = pReport->getYesterday();
     if (pYesterday->getWind() >= BLUSTERY) 
         roll += 20;

     /* limit to boundaries 1-100 */
     if (roll < 1) 
         roll = 1;
     if (roll > 100) 
         roll = 100;

     /* find wind type */
	 CClimate* pClimate = pReport->getClimate();
	 int nMonth = pReport->getMonth();
     for (int i = GALE; i >= CALM; i--)
         if (roll <= pClimate->getWind(nMonth, i)) 
             m_nType = i;
 }
